==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>Prednastavené pre Nové výkresy</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Nastavenie Kótovania</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Kótovanie</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scientific</source>
        <translation>Vedecký</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Desatinný</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Strojársky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Architektonický</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Zlomkový</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Stupne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Stupne/min/sek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Gradiány</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radiány</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Prehľad</translation>
    </message>
    <message>
        <location line="+198"/>
        <source>Unit / Format</source>
        <translation>Jednotka / Formát</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>Pre zobrazenie kót vo formátoch &apos;Architektonický&apos; alebo &apos;Strojársky&apos; musia byť nastavené jednotky v &apos;Palcoch&apos; alebo &apos;Stopách&apos;. Formát zmenený na &apos;Desatinný&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Veľkosti</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Zachovať pomer</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Výška Textu:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Odsadenie vynášacej čiary:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Presah vynášacej čiary:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Vzdialenosť textu od kótovacej čiary:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Veľkosť šípky:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Mierka veľkosti:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Typ šípky</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Šípka</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Architektonický</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Typ písma pre kóty:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translation>Štýl kótovania</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Lineárne Kóty</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Formát:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>P&amp;resnosť:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Zobraziť koncové nuly</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Uhlové Kóty</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>F&amp;ormát:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>Pre&amp;snosť:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Náhľad</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translation>Prednastavené pre Nové výkresy</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Nastavenie Kótovania</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Kótovanie</translation>
    </message>
    <message>
        <location line="+108"/>
        <source>point</source>
        <translation>bodka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>comma</source>
        <translation>čiarka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>space</source>
        <translation>medzera</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Scientific</source>
        <translation>Vedecký</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Desatinný</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Strojársky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Architektonický</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Zlomkový</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Stupne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Stupne/min/sek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Gradiány</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radiány</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Prehľad</translation>
    </message>
    <message>
        <location line="+209"/>
        <source>Unit / Format</source>
        <translation>Jednotka / Formát</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>Pre zobrazenie kót vo formátoch &apos;Architektonický&apos; alebo &apos;Strojársky&apos; musia byť nastavené jednotky v &apos;Palcoch&apos;. Formát zmenený na &apos;Desatinný&apos;.</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">Pre zobrazenie kót vo formátoch &apos;Architektonický&apos; alebo &apos;Strojársky&apos; musia byť nastavené jednotky v &apos;Palcoch&apos; alebo &apos;Stopách&apos;. Formát zmenený na &apos;Desatinný&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Veľkosti</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Zachovať pomer</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Výška Textu:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Odsadenie vynášacej čiary:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Presah vynášacej čiary:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Vzdialenosť textu od kótovacej čiary:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Veľkosť šípky:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Mierka veľkosti:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Typ šípky</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Šípka</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Architektonický</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Typ písma pre kóty:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Number Format</source>
        <translation>Číselný formát</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Decimal separator:</source>
        <translation>Oddeľovač desatinných miest:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Label Format</source>
        <translation>Štýl kótovania</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Lineárne Kóty</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Formát:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>P&amp;resnosť:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Zobraziť koncové nuly</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Uhlové Kóty</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>F&amp;ormát:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>Pre&amp;snosť:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Náhľad</translation>
    </message>
</context>
</TS>
